@@ -3,11 +3,12 @@
 
 register_tasks = function() {
   x = getFromNamespace("mlr_tasks", ns = "mlr3")
-  x$add("titanic", get_titanic_task())
-  x$add("kc_housing", get_kc_housing_task())
-  x$add("optdigits", get_optdigits_task())
-  x$add("moneyball", get_moneyball_task())
-  x$add("ilpd", get_ilpd_task())
+  x$add("titanic", get_titanic_task)
+  x$add("kc_housing", get_kc_housing_task)
+  x$add("optdigits", get_optdigits_task)
+  x$add("moneyball", get_moneyball_task)
+  x$add("ilpd", get_ilpd_task)
+  x$add("bike_sharing", get_bike_sharing_task)
 }
 
 .onLoad = function(libname, pkgname) { # nolint
